function [success,g,d,u,v] = PLS (X,Y)
% Standard PLS Algorithm --- Partial Least Squares 
%
% INPUT:
%
% X: data matrix of independent variables
% Y: data matrix of dependent variables
%
% OUTPUT:
%
% g: weight variable about X
% d: weight variable about Y
% u,v: score variables for X,Y
% success: a binary variable to indicate whether successfully run 
%          the pls algorithm
%

[rX,cX] = size(X);
[rY,cY] = size(Y);
% Input check
if(rX ~= rY)
    error('Please input matrices X and Y with same number of rows.')
end
%%%%%%%%%%%%%%%%%%%%%%% Preprocess the data %%%%%%%%%%%%%%%%%%%%%%%%%
X = zscore(X);
Y = zscore(Y);
%%%%%%%%%%%%%%%%%%%%%%%%% Initialization %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
tol = 1e-10;
maxiter = 500;

g = zeros(cX,1);
d = zeros(cY,1);
u = zeros(rX,1);
randCol = randi(cY,1);
v = Y(:,randCol);
% v = ones(rX,1);

success = 0;
iter = 0;
res = Inf;

%%%%%%%%%%%%%%%%%%%%%%%%% Main body of algorithm %%%%%%%%%%%%%%%%%%%%%%%%
% Update each variable iteratively
while (res > tol) && (iter < maxiter)
    u_old = u;
    g = X'*v/(v'*v);
    g = g/norm(g);
    u = X*g;
    d = Y'*u/(u'*u);
    d = d/norm(d);
    v = Y*d;
    iter = iter + 1;
    res = sum((u - u_old).^2);
end

success = 1;

if iter == maxiter
    s = ['Standard PLS Algorithm: Maximum number of iterations (' num2str(maxiter) ...
        ') reached before convergence'];
    fprintf(1,'%s\n',s);
    success = 0;
end

end


