function params = SNPLS_params(thrNet_list,thrXc_list,thrYc_list,delta_list)
% Construct a structure variable containing all the parameters needed for 
% the algorithm.
%
% INPUT:
%
% thrXc_list: thresholds for the columns of matrix X.
% thrYc_list: thresholds for the columns of matrix Y.
% thrNet_list: thresholds for the constraint about network.
% delta_list: for the equality constraint.
%
% OUTPUT:
%
% params: a structure containing all necessary parameters needed to 
%         run this program.
%

maxIter = 500; % maxIter: The maximal iteration steps
epsilon = 10^(-6); % epsilon: This value is used for judging stop of iteration.

combparams = combinelist(thrNet_list,thrXc_list);
combparams = combinelist(combparams,thrYc_list);
combparams = combinelist(combparams,delta_list);

[nparam,m] = size(combparams);
params.param = cell(nparam,1);
for i = 1:nparam,
    params.param{i} = SNPLS_param(combparams(i,1),combparams(i,2),...
        combparams(i,3),combparams(i,4),maxIter,epsilon);
end
params.combparams = combparams;
params.maxIter = maxIter;
params.epsilon = epsilon;
end

%%
function comblist = combinelist(list1,list2)
[n1,m1] = size(list1);
[n2,m2] = size(list2);
n_comb = n1*n2;
m_comb = m1 + m2;
comblist = zeros(n_comb,m_comb);
for i = 1:n1
    comblist(((i-1)*n2+1):(i*n2),1:m1) = repmat(list1(i,:),n2,1);
end
comblist(:,(m1+1):m_comb) = repmat(list2,n1,1);
end

function param = SNPLS_param(thrNet,thrXc,thrYc,delta,maxIter,epsilon)
if (nargin == 4),
    maxIter = 500; 
    epsilon = eps;
end

param.thrNet  = thrNet;
param.thrXc = thrXc;
param.thrYc  = thrYc;
param.maxIter = maxIter;
param.epsilon = epsilon;
param.delta = delta;

end



