function SNPLS_plot_XY(X,Y,fig,figure_title,colormap_type,vectorForRank)
% Plot the heatmap of data blocks.
%
% INPUT:
%
% X,Y: input data.
% fig: figure No.
% figure_title: the title of figure.
% colormap_type: cell(1 x 2), a parameter for heatmaps of these four
%                matrices. options for it are: 'blue-yellow'; 'green-red';
%               'yellow'; 'blue-white-red'; 'default'.
% vectorForRank: structure variable, containing four vectors ---
%                u,v,g,d
%
K = size(Y,1); % # samples
if nargin == 5,
    sampleSort = [1:K]'; % keep original order
    XfeatureSort = [1:size(X,2)]';
    YfeatureSort = [1:size(Y,2)]';
else % reorder the four matrices by the given vectors.
    [tmp,sampleSort] = sort(vectorForRank.u,'descend');
    [tmp,XfeatureSort] = sort(vectorForRank.g,'descend');
    [tmp,YfeatureSort] = sort(vectorForRank.d,'descend');
end

nTopRank = max(size(X,2),size(Y,2));
listTopRankSample = 1:min(K,nTopRank);

figure(fig);
set(gcf,'name',figure_title);

%%%%%%%%%%%%%%%%%%%%%%% X %%%%%%%%%%%%%%%%%%%%%%%
s(1) = subplot(1,2,1);
C = exp_colormap(colormap_type,64);
h = image(X(sampleSort(listTopRankSample),XfeatureSort));
colormap(gca,C);
set(h,'CDataMapping','scaled');

set(gca,'FontSize',14,'XTick',zeros(0,1),'XTickLabel',{},...
    'YTick',zeros(0,1),'YTickLabel',{})
title(s(1),'X');

%%%%%%%%%%%%%%%%%%%%%%% Y %%%%%%%%%%%%%%%%%%%%%%%
s(2) = subplot(1,2,2);
h = image(Y(sampleSort(listTopRankSample),YfeatureSort));
colormap(gca,C);
set(h,'CDataMapping','scaled');
set(gca,'FontSize',14,'XTick',zeros(0,1),'XTickLabel',{},...
    'YTick',zeros(0,1),'YTickLabel',{})
title(s(2),'Y');

end

