function SNPLS_plot_distribution(nSample,Ind,Comodule,fig,figure_title)
% Plot a histogram figure to show module size distribution
%
% INPUT:
%
% nSample: #samples.
% Ind: a matrix(2 x 2), each row is for the start and end index for X or Y 
%      blocks
% Comodule: cell(nfactor x 3),the comodules content.
% fig: figure No.
% figure_title: the title of figure.
%
[K,nblock] = size(Comodule);
nbX = size(Ind,1);

figure(fig);
set(gcf,'name',figure_title);

moduleMat = zeros(nSample,K);
for imodule = 1:K
    ele = Comodule{imodule,1};
    moduleMat(ele,imodule) = 1;
end
sta1 = sum(moduleMat,1);

subplot(1,nblock,1);
[nelements,centers] = hist(sta1,4);
bar(centers,nelements,'FaceColor',[0.75 0.86 0.77],...
    'EdgeColor',[0.75 0.86 0.77],'BarWidth',0.6)
title('Samples','FontSize',14)
ylabel('Frequency','FontSize',14)

maxVal = max(nelements);
ylim([0,maxVal+1])
yInterVal = max(1,fix(maxVal/2));

set(gca,'YTick',[0,yInterVal:yInterVal:maxVal],...
    'YTickLabel',[0,yInterVal:yInterVal:maxVal])

clear sta1 moduleMat maxVal yInterVal

for aa = 1:nbX
    coli = Ind(aa,1):Ind(aa,2);
    rbX = length(coli);
    moduleMat = zeros(rbX,K);
    for imodule = 1:K
        ele = Comodule{imodule,aa+1};
        moduleMat(ele,imodule) = 1;
    end
    sta1 = sum(moduleMat,1);
    
    subplot(1,nblock,1+aa);
    [nelements,centers] = hist(sta1,4);
    bar(centers,nelements,'FaceColor',[0.75 0.86 0.77],...
        'EdgeColor',[0.75 0.86 0.77],'BarWidth',0.6)
    title(['Feature type' num2str(aa)],'FontSize',14)
    
    maxVal = max(nelements);
    ylim([0,maxVal+1])
    yInterVal = max(1,fix(maxVal/2));
    
    set(gca,'YTick',[0,yInterVal:yInterVal:maxVal],...
        'YTickLabel',[0,yInterVal:yInterVal:maxVal])
    
    clear sta1 moduleMat
    
end
end