function SNPLS_plot_results(X,Y,fig,figure_title,colormap_type,vectorForRank)
%
% INPUT:
%
% X,Y: input data.
% fig: figure No.
% colormap_type: cell(1 x 2), a parameter for heatmaps of these four
%                matrices. options for it are: 'blue-yellow'; 'green-red';
%               'yellow'; 'blue-white-red'; 'default'.
% vectorForRank: structure variable, containing 5 variables ---
%                g,d,u,v,comodule
%

comodule = vectorForRank.comodule;
g = vectorForRank.g;
d = vectorForRank.d;
u = vectorForRank.u;
u = u/sqrt(u'*u);
v = vectorForRank.v;
v = v/sqrt(v'*v);
[rX,cX] = size(X);
[rY,cY] = size(Y);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Reorder the selected samples and randomly select the same number of
% samples.
selected_samples = comodule{1};
selected_samples = sort_vector(u(selected_samples),selected_samples);
if (isempty(selected_samples)),
    error('There is no samples in the identified comodule.');
end
rand_ri = randsample(setdiff(1:rX,selected_samples),length(selected_samples));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(fig);
set(gcf,'name',figure_title);
C = exp_colormap(colormap_type,64);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% For X block, reorder the selected features and then select the same
% number of other features.
XX = rescale(X);
gi = comodule{2};
gi = sort_vector(g(gi),gi);
objMat = XX(selected_samples,gi);
rand_ci = randsample(setdiff(1:cX,gi),length(gi));

tempMat21 = XX(rand_ri,gi);
tempMat12 = XX(selected_samples,rand_ci);
tempMat22 = XX(rand_ri,rand_ci);
tempMat = [objMat tempMat12;tempMat21 tempMat22];
clear tempMat21 tempMat12 tempMat22 rand_ci XX objMat

subplot(2,2,1);
image(tempMat*64);
colormap(gca,C);
set(gca,'FontSize',14,'YTick',zeros(0,1), 'YTickLabel',{},'XTick',zeros(0,1),...
    'XTickLabel',{});
% Using a rectangle to frame the module.
rectangle('Position',[0.6,0.6,length(gi)-0.1,...
    length(selected_samples)-0.1],'LineWidth',3,'EdgeColor',[1 1 0])

title('X');
xlabel({'feature subset ', ['(2 x ' num2str(length(gi)) ')']});
ylabel(['sample (2 x ' num2str(length(selected_samples)) ')']);
clear tempMat gi

%%%%%%%%%%%%%%%%%%%%%%%%%% For Y %%%%%%%%%%%%%%%%%%%%%%%%%%%
YY = rescale(Y);
di = comodule{3};
di = sort_vector(d(di),di);
objMat = YY(selected_samples,di);
rand_ci = randsample(setdiff(1:cY,di),length(di));

tempMat21 = YY(rand_ri,di);
tempMat12 = YY(selected_samples,rand_ci);
tempMat22 = YY(rand_ri,rand_ci);
tempMat = [objMat tempMat12;tempMat21 tempMat22];
clear tempMat21 tempMat12 tempMat22 rand_ci YY objMat

subplot(2,2,2);
image(tempMat*64);
colormap(gca,C);
set(gca,'FontSize',14,'YTick',zeros(0,1), 'YTickLabel',{},'XTick',zeros(0,1),...
    'XTickLabel',{});
% Using a rectangle to frame the module.
rectangle('Position',[0.6,0.6,length(di)-0.1,...
    length(selected_samples)-0.1],'LineWidth',3,'EdgeColor',[1 1 0])

title('Y');
xlabel({'feature subset ', ['(2 x ' num2str(length(di)) ')']});
% ylabel(['sample (2 x ' num2str(length(selected_samples)) ')']);
clear tempMat di

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
subplot(2,2,3);
obj_u = u(selected_samples,1);
obj_v = v(selected_samples,1);
plot(obj_u,obj_v,'*k');
set(gca,'FontSize',14)
xlabel('u')
ylabel('v')
maxVal0 = roundn(max([obj_u;obj_v]),-2);
minVal0 = roundn(min([obj_u;obj_v]),-2);
interVal = roundn((maxVal0 - minVal0)/3,-2);
maxVal = maxVal0 + interVal;
minVal = minVal0 - interVal;

xlim([minVal,maxVal]);
ylim([minVal,maxVal]);

set(gca,'XTick',[minVal0,maxVal0],'XTickLabel',[minVal0,maxVal0],...
    'YTick',[minVal0,maxVal0],'YTickLabel',[minVal0,maxVal0])

clear minVal0 maxVal0 minVal maxVal interVal
end


function newLabels = sort_vector(vec,labels)
[tmp,sorti] = sort(vec);
newLabels = labels(sorti);
end

function newX = rescale(X)
minX = min(min(X));
maxX = max(max(X));
if (minX == maxX),
    newX = X;
else
    newX = (X-minX)/(maxX-minX);
end
end
