function [param_idx,cv_scores] = SNPLS_select_param(X,Y,L,params)
% Select the parameter combination that has the minimal cv_score.
%
% INPUT:
%
% X: matrices (objects x X-variables)
% Y: matrix (objects x Y-variables)
% L: normalized Laplacian matrix for the network.
% params: a structure containing all necessary parameters needed to run
%         this program.
%
% OUTPUT:
%
% param_idx: the index of selected optimal parameters
% cv_scores: vector(nparam x 1), each one value means the cross-validation
%            score for each parameter combination
%
nparam = length(params.param);
cv_scores = zeros(nparam,1);
randRowPartitions = params.randRowPartitions;
step = ceil(nparam/10);
if (nparam > 1)
    for i = 1:nparam,
        if (rem(i,step) == 0), 
            fprintf('%d%%\n',floor(i*100/nparam)); 
        end
        cv_scores(i) = SNPLS_getCVscore(X,Y,L,params.param{i},randRowPartitions);
    end
    fprintf('\n');
    [mincv,param_idx] = min(cv_scores);
    if(mincv == Inf)
        error('The given thresholds combinations are not proper for the input data!')
    end
elseif (nparam == 1)
    param_idx = 1;
end
end
